@@ -3,6 +3,8 @@ from importlib import resources
 from configparser import ConfigParser
 import connecty, discord, string
 import colorama
+import multiprocessing
+from importlib import resources
 import types
 colorama.init()
 
@@ -35,6 +37,26 @@ async def init():
         sec = config[sec]
         await bot.register(list(int(ids) for ids in sec["channels"].split()))
 
+"""
+try:
+    import pystray
+    try:
+        from PIL import Image
+        with resources.path('connecty', 'icon.png') as file: icon = Image.open(file)
+    except ImportError:
+        icon = None
+    tray = pystray.Icon(name='connecty', icon=icon)
+    def shutdown():
+        tray.stop()
+        bot.close()
+        exit()
+    tray.menu = pystray.Menu(pystray.MenuItem('default', shutdown, default=True))
+    process = multiprocessing.Process(target=tray.run)
+    process.start()
+except ImportError: pass
+"""
+
 
 def start(): bot.run(bot_config["token"])
-if __name__ == "__main__": start()
\ No newline at end of file
+if __name__ == "__main__":
+    start()
\ No newline at end of file
